<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>AppItem</name>
    <message>
        <source>Move to Trash</source>
        <translation>Verplaatsen naar prullenbak</translation>
    </message>
</context>
<context>
    <name>dock::AppItem</name>
    <message>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Losmaken</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Vastmaken</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Afsluiten forceren</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Alle vensters sluiten</translation>
    </message>
</context>
<context>
    <name>dock::DockGlobalElementModel</name>
    <message>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Losmaken</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Vastmaken</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Afsluiten forceren</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Alles sluiten</translation>
    </message>
</context>
<context>
    <name>dock::TaskManager</name>
    <message>
        <source>%1 files</source>
        <translation>%1 bestanden</translation>
    </message>
</context>
</TS>